django-crwyoauth
===================

简介
===================
django oauth 2.0 实现。

运行环境
===================

 * Python2.7
 * Django
 * Works on Linux, Mac OSX

依赖包
===================
 * Django >= 1.10.3
 * django-braces >= 1.9.0

安装
===================

快速安装::

    pip install django-crwyoauth

or
前往下载: https://pypi.python.org/pypi/django-crwyoauth/1.0.0/

使用手册
===================
在这里: http://django-crwyoauth.readthedocs.io/zh_CN/1.0.0/

